@@ -9,10 +9,10 @@
 #include <qdatetime.h>
 
 
-#include <kapp.h>
+#include <kapplication.h>
 #include <klocale.h>
 #include <kglobal.h>
-#include <kstddirs.h>
+#include <kstandarddirs.h>
 #include <kcolordialog.h>
 #include <kconfig.h>
 
@@ -35,13 +35,13 @@ MapWidget::MapWidget(bool applet, bool restore, QWidget *parent, const char *nam
 {
   // this ugly construction is necessary so we don't load 
   // the map twice.
-  _theme = "earth";
+  _theme = "depths";
   if (restore)
     {
       KConfig *config = kapp->config();
       if (applet)
 	config = new KConfig("kwwwappletrc");
-      _theme = config->readEntry("Theme", "earth");
+      _theme = config->readEntry("Theme", "depths");
       if (applet)
 	delete config;
     }
@@ -57,23 +57,23 @@ MapWidget::MapWidget(bool applet, bool restore, QWidget *parent, const char *nam
   int id;
   _flagPopup = new QPopupMenu(this);
   QPixmap flag = QPixmap(locate("data", "kworldclock/pics/flag-red.png"));
-  id = _flagPopup->insertItem(QIconSet(flag), i18n("Add &red"), this, SLOT(addFlag(int)));
+  id = _flagPopup->insertItem(QIconSet(flag), i18n("Add &Red"), this, SLOT(addFlag(int)));
   _flagPopup->setItemParameter(id, 0);
   flag = QPixmap(locate("data", "kworldclock/pics/flag-green.png"));
-  id = _flagPopup->insertItem(QIconSet(flag), i18n("Add &green"), this, SLOT(addFlag(int)));
+  id = _flagPopup->insertItem(QIconSet(flag), i18n("Add &Green"), this, SLOT(addFlag(int)));
   _flagPopup->setItemParameter(id, 1);
   flag = QPixmap(locate("data", "kworldclock/pics/flag-blue.png"));
-  id = _flagPopup->insertItem(QIconSet(flag), i18n("Add &blue"), this, SLOT(addFlag(int)));
+  id = _flagPopup->insertItem(QIconSet(flag), i18n("Add &Blue"), this, SLOT(addFlag(int)));
   _flagPopup->setItemParameter(id, 2);
-  id = _flagPopup->insertItem(i18n("Add &custom..."), this, SLOT(addFlag(int)));
+  id = _flagPopup->insertItem(i18n("Add &Custom..."), this, SLOT(addFlag(int)));
   _flagPopup->setItemParameter(id, 3);
   _flagPopup->insertSeparator();
-  _flagPopup->insertItem(i18n("&Remove flag"), this, SLOT(removeFlag())); 
+  _flagPopup->insertItem(i18n("&Remove Flag"), this, SLOT(removeFlag()));
 
   _themePopup = new QPopupMenu(this);
   _themes = MapLoader::themes();
   int cnt=0;
-  QListIterator<MapTheme> it(_themes);
+  QPtrListIterator<MapTheme> it(_themes);
   for ( ; it.current(); ++it)
     {
       int id = _themePopup->insertItem(it.current()->name(), this, SLOT(themeSelected(int)));
@@ -91,7 +91,7 @@ MapWidget::MapWidget(bool applet, bool restore, QWidget *parent, const char *nam
     _popup->insertItem(i18n("&Clocks"), _clocksPopup);
 
   _popup->insertSeparator();
-  _popup->insertItem(i18n("&Map theme"), _themePopup);
+  _popup->insertItem(i18n("&Map Theme"), _themePopup);
   _illuminationID = _popup->insertItem(i18n("Show &Daylight"), this, SLOT(toggleIllumination()));
   _citiesID = _popup->insertItem(i18n("Show &Cities"), this, SLOT(toggleCities()));
   _flagsID = _popup->insertItem(i18n("Show F&lags"), this, SLOT(toggleFlags()));
@@ -99,7 +99,7 @@ MapWidget::MapWidget(bool applet, bool restore, QWidget *parent, const char *nam
   if (!applet)
     {
       _popup->insertSeparator();
-      _popup->insertItem(i18n("&Save settings"), this, SLOT(slotSaveSettings()));
+      _popup->insertItem(i18n("&Save Settings"), this, SLOT(slotSaveSettings()));
     }
 
   _popup->insertSeparator();
@@ -127,6 +127,8 @@ MapWidget::~MapWidget()
       save(conf);
       delete conf;
     }
+  delete _cityList;
+  delete _flagList;
 }
 
 
@@ -136,7 +138,7 @@ void MapWidget::load(KConfig *config)
   setIllumination(config->readBoolEntry("Illumination", true));
   setFlags(config->readBoolEntry("Flags", true));
 
-  setTheme(config->readEntry("Theme", "earth"));
+  setTheme(config->readEntry("Theme", "depths"));
 
   _flagList->load(config);  
 }
@@ -381,12 +383,13 @@ void MapWidget::showIndicator(QPoint pos)
   int w = _cityIndicator->width();
   int h = _cityIndicator->height();
 
-  if (pos.x()+w+10 > QApplication::desktop()->width())
+  QRect desk = QApplication::desktop()->screenGeometry(QApplication::desktop()->screenNumber(pos));
+  if (pos.x()+w+10 > desk.right())
     pos.setX(pos.x()-w-5);
   else 
     pos.setX(pos.x()+10);
 
-  if (pos.y()+h+10 > QApplication::desktop()->height())
+  if (pos.y()+h+10 > desk.bottom())
     pos.setY(pos.y()-h-5);
   else
     pos.setY(pos.y()+10);
@@ -402,7 +405,7 @@ void MapWidget::setTheme(QString theme)
 {
   _theme = theme;
 
-  QListIterator<MapTheme> it(_themes);
+  QPtrListIterator<MapTheme> it(_themes);
   for ( ; it.current(); ++it)
    _themePopup->setItemChecked(it.current()->ID(), theme == it.current()->tag());
  
